Downloader

Struct Downloader 

pub struct Downloader {
    pub link: Link,
    pub task_limit: TaskType,
    pub outdir: String,
    pub retry: RetryType,
    pub video_only: bool,
    pub image_only: bool,
    pub multi_progress: Arc<Mutex<MultiProgress>>,
    pub info: Arc<Mutex<DownloaderInfo>>,
    pub verbose: bool,
    pub creator_name: Arc<Mutex<Option<String>>>,
}

Fields

link: Linktask_limit: TaskTypeoutdir: Stringretry: RetryTypevideo_only: boolimage_only: boolmulti_progress: Arc<Mutex<MultiProgress>>info: Arc<Mutex<DownloaderInfo>>verbose: boolcreator_name: Arc<Mutex<Option<String>>>

Implementations

Source

impl Downloader

pub async fn download_post( &mut self, pid: String, status: StatusBar, ) -> Result<DownloaderInfo>

Downloads all files in a specific post

Arguments
  • pid - post id to download
  • page - Current page information for progress display
Source

impl Downloader

pub async fn fetch_page(&self) -> Result<Vec<String>>

This function will collect all post id from page(s).

Source

impl Downloader

pub async fn get_posts_from_page(&mut self, url: &str) -> Result<Vec<String>>

Fetches all post attachments from a specific page URL

Arguments
  • url - The URL of the post page
Returns
  • Result<Vec<String>> - Vector of file paths to download
Source

impl Downloader

pub fn print_parameters(&self)

pub fn new( link: Link, task_limit: TaskType, outdir: String, retry: RetryType, video_only: bool, image_only: bool, verbose: bool, ) -> Self

pub async fn fetch_post_id(&self) -> Result<Vec<String>>

Collect all posts id from sigle post or pages.

pub async fn all(&mut self) -> Result<()>

Main function to download all content.

Source

impl Downloader

pub async fn failed_file(&self) -> Vec<String>

pub async fn print_reports(&self)